From 94fcf9a7c905f0d0ddb9f49ec51c4c07c593cb18 Mon Sep 17 00:00:00 2001
From: Melvin Groenhoff <m.groenhoff@spiritit.com>
Date: Mon, 14 Nov 2016 15:18:50 +0100
Subject: [PATCH] Adjust the declaration file to match the exporting method in
 the source code

---
 mobile-detect.d.ts | 88 +++++++++++++++++++++++++---------------------
 1 file changed, 47 insertions(+), 41 deletions(-)

diff --git a/mobile-detect.d.ts b/mobile-detect.d.ts
index d9e6d2a..57aa1ac 100644
--- a/mobile-detect.d.ts
+++ b/mobile-detect.d.ts
@@ -1,48 +1,9 @@
 
-export interface MobileDetectRules {
-	[key: string]: string|RegExp;
-}
-
-export interface MobileDetectComplexRules {
-	[key: string]: string|RegExp|string[]|RegExp[];
-}
-
-export interface MobileDetectImpl {
-	mobileDetectRules: {
-		phones: MobileDetectRules;
-		tablets: MobileDetectRules;
-		oss: MobileDetectRules;
-		uas: MobileDetectRules;
-		props: MobileDetectComplexRules;
-		utils: MobileDetectRules;
-	};
-	detectMobileBrowsers: {
-		fullPattern: RegExp;
-		shortPattern: RegExp;
-		tabletPattern: RegExp;
-	};
-	FALLBACK_PHONE: string;
-	FALLBACK_TABLET: string;
-	FALLBACK_MOBILE: string;
-
-	findMatch(rules: MobileDetectRules, userAgent: string): string;
-	findMatches(rules: MobileDetectRules, userAgent: string): string[];
-	getVersionStr(propertyName: string, userAgent: string): string;
-	getVersion(propertyName: string, userAgent: string): number;
-	prepareVersionNo(version: string): number;
-	isMobileFallback(userAgent: string): boolean;
-	isTabletFallback(userAgent: string): boolean;
-	prepareDetectionCache(cache: Object, userAgent: string, maxPhoneWidth?: number): void;
-	mobileGrade(md: MobileDetect): string;
-	detectOS(userAgent: string): string;
-	getDeviceSmallerSide(): number;
-}
-
-export declare class MobileDetect {
+declare class MobileDetect {
 	static version: string;
 	static isPhoneSized(maxPhoneWidth?: number): boolean;
 	// only used internally; if necessary, one can replace, intercept or augment particular methods or values
-	static _impl: MobileDetectImpl;
+	static _impl: MobileDetect.MobileDetectImpl;
 
 	constructor(userAgent: string, maxPhoneWidth?: number);
 
@@ -62,3 +23,48 @@ export declare class MobileDetect {
 	isPhoneSized(maxPhoneWidth?: number): boolean;
 	mobileGrade(): string;
 }
+
+declare namespace MobileDetect {
+	interface MobileDetectRules {
+		[key: string]: string|RegExp;
+	}
+
+	interface MobileDetectComplexRules {
+		[key: string]: string|RegExp|string[]|RegExp[];
+	}
+
+	interface MobileDetectImpl {
+		mobileDetectRules: {
+			phones: MobileDetectRules;
+			tablets: MobileDetectRules;
+			oss: MobileDetectRules;
+			uas: MobileDetectRules;
+			props: MobileDetectComplexRules;
+			utils: MobileDetectRules;
+		};
+		detectMobileBrowsers: {
+			fullPattern: RegExp;
+			shortPattern: RegExp;
+			tabletPattern: RegExp;
+		};
+		FALLBACK_PHONE: string;
+		FALLBACK_TABLET: string;
+		FALLBACK_MOBILE: string;
+
+		findMatch(rules: MobileDetectRules, userAgent: string): string;
+		findMatches(rules: MobileDetectRules, userAgent: string): string[];
+		getVersionStr(propertyName: string, userAgent: string): string;
+		getVersion(propertyName: string, userAgent: string): number;
+		prepareVersionNo(version: string): number;
+		isMobileFallback(userAgent: string): boolean;
+		isTabletFallback(userAgent: string): boolean;
+		prepareDetectionCache(cache: Object, userAgent: string, maxPhoneWidth?: number): void;
+		mobileGrade(md: MobileDetect): string;
+		detectOS(userAgent: string): string;
+		getDeviceSmallerSide(): number;
+	}
+}
+
+export = MobileDetect;
+
+export as namespace MobileDetect;
